@@ -17,10 +17,8 @@ def callback():
 
 def get_template_path(template_name):
     script_path = os.path.abspath(__file__)
-    module_path = os.path.dirname(script_path)
-    project_path = os.path.dirname(module_path)
-    cookiecutters_path = os.path.join(project_path, "templates")
-    return os.path.join(cookiecutters_path, template_name)
+    templates_path = os.path.join(script_path, "templates")
+    return os.path.join(templates_path, template_name)
     
 
 def activate_venv():
@@ -39,7 +37,7 @@ def activate_venv():
 
 @app.command()
 def main(template_name):
-    cookiecutter(template_name)
-
+    template_path = get_template_path(template_name)
+    cookiecutter(template_path)
     activate_venv()
 
